Bug 7092

Summary: linux-yocto: improve do_patch performance
Product: [Build System, Metadata & Runtime] OE-Core Reporter: Bruce Ashfield <bruce.ashfield>
Component: kernelAssignee: Bruce Ashfield <bruce.ashfield>
Status: RESOLVED FIXED QA Contact:
Severity: enhancement    
Priority: Medium CC: bruce.ashfield, sgw, tom.zanussi
Version: 1.8   
Target Milestone: 1.8 M3   
Hardware: x86   
OS: Multiple   
Whiteboard:
OS type for building Yocto: --- Type of Regression: ---
Verified: Documentation change: No (bug/feature does not impact docs)

Description Bruce Ashfield 2014-12-19 16:14:45 UTC
When gathering and validating the patches during do_patch() linux-yocto consumes
time with sanity checks and per-patch validation. In the majority of cases, this is
unnecessary and can be short cut / optimized.

As part of the developer experience efforts, we can make the optimized case be the
default.
Comment 1 Bruce Ashfield 2015-01-27 16:16:02 UTC
We have patches that improve the patch phase by 20 seconds, and it should be 
constant no matter how large the queue of patches to be validated. More testing
and they'll be submitted.
Comment 2 Bruce Ashfield 2015-02-17 21:10:02 UTC
The do_patch time improvements have been merged to oe-core. This is closed for 1.8.
Future work will happen under new bugzilla entries.